pywurfl.serialize.Serialize

Package pywurfl :: Module serialize :: Class Serialize |
[hide private]
[frames] | no frames]

# Class Serialize

source code

    object --+
             |
            Serialize

Instance Methods | [hide private]
__init__(self, devices) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
_find_group(self, cap) | source code
_get_value(self, x) | source code
_walk(self, device, devices) | source code
to_xml(self, filename) Serialize pywurfl's WURFL class hierarchy to xml | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, devices) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### to_xml(self, filename) | source code
Serialize pywurfl's WURFL class hierarchy to xml Parameters: `filename` (string) - The filename to save the hierarchy to